@@ -1626,7 +1626,7 @@ gdm_xdmcp_send_decline (GdmXdmcpManager         *manager,
 	char            *host;
 
 	gdm_address_get_info (clnt_sa, &host, NULL);
-	g_debug ("XMDCP: Sending DECLINE to %s", host);
+	g_debug ("XDMCP: Sending DECLINE to %s", host);
 	g_free (host);
 
 	authentype.data   = (CARD8 *) 0;
@@ -1736,6 +1736,7 @@ gdm_xdmcp_display_alloc (GdmXdmcpManager         *manager,
 
 	gdm_hostent_free (he);
 
+	d->windowpath            = NULL;
 	d->slave_notify_fd       = -1;
 	d->master_notify_fd      = -1;
 	d->xsession_errors_bytes = 0;
@@ -2473,7 +2474,7 @@ decode_packet (GIOChannel      *source,
 
 	res = XdmcpFill (manager->priv->socket_fd, &manager->priv->buf, (XdmcpNetaddr)&clnt_sa, &sa_len);
 	if G_UNLIKELY (! res) {
-		g_debug (_("XMCP: Could not create XDMCP buffer!"));
+		g_debug (_("XDMCP: Could not create XDMCP buffer!"));
 		return TRUE;
 	}
 
@@ -2485,7 +2486,7 @@ decode_packet (GIOChannel      *source,
 
 	if G_UNLIKELY (header.version != XDM_PROTOCOL_VERSION &&
 		       header.version != GDM_XDMCP_PROTOCOL_VERSION) {
-		g_warning (_("XMDCP: Incorrect XDMCP version!"));
+		g_warning (_("XDMCP: Incorrect XDMCP version!"));
 		return TRUE;
 	}
 
